@@ -2,7 +2,7 @@
  * Programmer(s): Cody J. Balos, Aaron Collier and Radu Serban @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2023, Lawrence Livermore National Security
+ * Copyright (c) 2002-2024, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -19,6 +19,14 @@
 
 #include "sundials/sundials_export.h"
 
+/* Indicates that the function will not report an error via last_err,
+   a return code. In C++, it is just defined as noexcept. */
+#if defined(__cplusplus)
+#define SUNDIALS_NOEXCEPT noexcept
+#else
+#define SUNDIALS_NOEXCEPT
+#endif
+
 #ifndef SUNDIALS_DEPRECATED_MSG
 #  define SUNDIALS_DEPRECATED_MSG(msg) __declspec(deprecated(msg))
 #endif
@@ -36,9 +44,9 @@
  * -----------------------------------------------------------------*/
 
 
-#define SUNDIALS_VERSION "6.7.0"
-#define SUNDIALS_VERSION_MAJOR 6
-#define SUNDIALS_VERSION_MINOR 7
+#define SUNDIALS_VERSION "7.0.0"
+#define SUNDIALS_VERSION_MAJOR 7
+#define SUNDIALS_VERSION_MINOR 0
 #define SUNDIALS_VERSION_PATCH 0
 #define SUNDIALS_VERSION_LABEL ""
 #define SUNDIALS_GIT_VERSION ""
@@ -48,11 +56,12 @@
  * SUNDIALS build information
  * -----------------------------------------------------------------*/
 
-#define SUNDIALS_C_COMPILER_HAS_MATH_PRECISIONS
-#define SUNDIALS_C_COMPILER_HAS_ISINF_ISNAN
-#define SUNDIALS_C_COMPILER_HAS_INLINE
+#define SUNDIALS_C_COMPILER_HAS_BUILTIN_EXPECT
+/* #undef SUNDIALS_C_COMPILER_HAS_ATTRIBUTE_ASSUME */
+#define SUNDIALS_C_COMPILER_HAS_BUILTIN_ASSUME
+/* #undef SUNDIALS_C_COMPILER_HAS_ASSUME */
 
-/* Define precision of SUNDIALS data type 'realtype'
+/* Define precision of SUNDIALS data type 'sunrealtype'
  * Depending on the precision level, one of the following
  * three macros will be defined:
  *     #define SUNDIALS_SINGLE_PRECISION 1
@@ -74,11 +83,6 @@
  */
 #define SUNDIALS_INDEX_TYPE int32_t
 
-/* Use std-c math functions
- * DEPRECATED SUNDIALS_USE_GENERIC_MATH
- */
-/* #undef SUNDIALS_USE_GENERIC_MATH */
-
 /* Use POSIX timers if available.
  *     #define SUNDIALS_HAVE_POSIX_TIMERS
  */
@@ -93,17 +97,11 @@
 /* BUILD SUNDIALS with profiling functionalities */
 /* #undef SUNDIALS_BUILD_WITH_PROFILING */
 
+/* Enable error checking within SUNDIALS */
+/* #undef SUNDIALS_ENABLE_ERROR_CHECKS */
+
 /* BUILD SUNDIALS with logging functionalities */
-#define SUNDIALS_LOGGING_LEVEL 0
-
-/* BUILD SUNDIALS with MPI-enabled logging */
-/* #undef SUNDIALS_LOGGING_ENABLE_MPI */
-
-/* Is snprintf available? */
-#define SUNDIALS_C_COMPILER_HAS_SNPRINTF_AND_VA_COPY
-#ifndef SUNDIALS_C_COMPILER_HAS_SNPRINTF_AND_VA_COPY
-#define SUNDIALS_MAX_SPRINTF_SIZE 
-#endif
+#define SUNDIALS_LOGGING_LEVEL 2
 
 /* Build metadata */
 #define SUN_C_COMPILER "Clang"
@@ -120,8 +118,8 @@
 
 #define SUN_BUILD_TYPE "Release"
 
-#define SUN_JOB_ID "20240502211032"
-#define SUN_JOB_START_TIME "20240502211032"
+#define SUN_JOB_ID "20240511132113"
+#define SUN_JOB_START_TIME "20240511132113"
 
 #define SUN_TPL_LIST "OPENMP;KLU;BLAS_LAPACK;PTHREAD"
 #define SUN_TPL_LIST_SIZE ""
@@ -298,65 +296,4 @@
 #define SUNDIALS_SUNNONLINSOL_FIXEDPOINT 1
 
 
-
-/* ------------------------------------------------------------------
- * SUNDIALS fortran configuration
- * -----------------------------------------------------------------*/
-
-
-/* Define Fortran name-mangling macro for C identifiers.
- * Depending on the inferred scheme, one of the following six
- * macros will be defined:
- *     #define SUNDIALS_F77_FUNC(name,NAME) name
- *     #define SUNDIALS_F77_FUNC(name,NAME) name ## _
- *     #define SUNDIALS_F77_FUNC(name,NAME) name ## __
- *     #define SUNDIALS_F77_FUNC(name,NAME) NAME
- *     #define SUNDIALS_F77_FUNC(name,NAME) NAME ## _
- *     #define SUNDIALS_F77_FUNC(name,NAME) NAME ## __
- */
-#define SUNDIALS_F77_FUNC(name,NAME) name ## _
-
-/* Define Fortran name-mangling macro for C identifiers
- * which contain underscores.
- */
-#define SUNDIALS_F77_FUNC_(name,NAME) name ## _
-
-/* Allow user to specify different MPI communicator
- * If it was found that the MPI implementation supports MPI_Comm_f2c, then
- *      #define SUNDIALS_MPI_COMM_F2C 1
- * otherwise
- *      #define SUNDIALS_MPI_COMM_F2C 0
- */
-
-
-
-/* ------------------------------------------------------------------
- * SUNDIALS inline macros.
- * -----------------------------------------------------------------*/
-
-
-/* Mark SUNDIALS function as inline.
- */
-#ifndef SUNDIALS_CXX_INLINE
-#define SUNDIALS_CXX_INLINE inline
-#endif
-
-#ifndef SUNDIALS_C_INLINE
-#ifdef SUNDIALS_C_COMPILER_HAS_INLINE
-#define SUNDIALS_C_INLINE inline
-#else
-#define SUNDIALS_C_INLINE
-#endif
-#endif
-
-#ifdef __cplusplus
-#define SUNDIALS_INLINE SUNDIALS_CXX_INLINE
-#else
-#define SUNDIALS_INLINE SUNDIALS_C_INLINE
-#endif
-
-/* Mark SUNDIALS function as static inline.
- */
-#define SUNDIALS_STATIC_INLINE static SUNDIALS_INLINE
-
 #endif /* _SUNDIALS_CONFIG_H */
